# python-test

[![CI](https://github.com/tagdots-dev/python-test/actions/workflows/ci.yaml/badge.svg?logo=github&labelColor=222222)](https://github.com/tagdots-dev/python-test/actions/workflows/ci.yaml) [![Code Coverage](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/tagdots-dev/python-test/refs/heads/badge/coverage.json)](https://github.com/tagdots-dev/python-test/actions/workflows/cron-coverage.yaml)

**pkg-15903** is a python test program. It runs a request call to your desired url and returns http status code.

```
$ pkg-15903 --url https://www.google.com
URL (https://www.google.com/) result: 200
```
